# cpalgo
The library is active since June 15, 2021.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install cpalgo
```

## Developers
[Narayanaa S R](https://srnarayanaa.me)

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[BSD](https://opensource.org/licenses/BSD-3-Clause)

## Project Status
This project is expected to be completed by November 2021.

## Templates to be covered in cpalgo

<details>
    <summary>Algebra</summary>
		Binary Exponentitation<br/>
		EGCD<br/>
		Linear Diophantine Equations<br/>
		Linear Sieves
</details>

___

<details>
    <summary>Query based Optimisation</summary>
		Sparse Table<br/>
		RMQ<br/>
		Square Root Decomposition<br/>
		Heavy Light Decomposition<br/>
		RMQ - Euler Tour
</details>

___

<details>
    <summary>Graph Optimisation</summary>
		Articulation<br/>
		DSU - Kruskal<br/>
		Tarjan off-line<br/>
		Fold Fulkerson - Max Flow<br/>
		Dinic - Max Flow<br/>
		Condensation Graph<br/>
		Fenwick Tree<br/>
		Segment Tree
</details>

___

<details>
    <summary>Computational Geometry</summary>
		Convex Hull - Graham's scan<br/>
		Convex Hull - Andrew Monotone<br/>
		S&I NlogN<br/>
		Lattice Points - Pick's algorithm
</details>

___